--[[
Copyright 2008, 2009 Erich Blume

   This file is part of Babel.

    Babel is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Babel is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Babel.  If not, see <http://www.gnu.org/licenses/>.
--]]

---------------------------------------------
-- UPVALUES                                --
---------------------------------------------

Babel = LibStub("AceAddon-3.0"):NewAddon("Babel", "AceEvent-3.0", "AceHook-3.0")
local ldb = LibStub:GetLibrary("LibDataBroker-1.1")

local defaults = {
	char = {
		language = 1,
		types = {
			["SAY"] = true,
			["YELL"] = true,
			["PARTY"] = true,
			["GUILD"] = true,
			["OFFICER"] = true,
			["RAID"] = true,
		}
	}
}

---------------------------------------------
-- MENU                                    --
---------------------------------------------

local function langToggle()
	Babel.db.char.types[UIDROPDOWNMENU_MENU_VALUE] = not Babel.db.char.types[UIDROPDOWNMENU_MENU_VALUE]
end

local function getCheckedSAY()
	return Babel.db.char.types.SAY
end

local function getCheckedYELL()
	return Babel.db.char.types.YELL
end

local function getCheckedPARTY()
	return Babel.db.char.types.PARTY
end

local function getCheckedGUILD()
	return Babel.db.char.types.GUILD
end

local function getCheckedOFFICER()
	return Babel.db.char.types.OFFICER
end

local function getCheckedRAID()
	return Babel.db.char.types.RAID
end

local menu_frame = CreateFrame("Frame", nil, UIParent, "UIDropMenuTemplate")

local menu_list = {
	{ -- SAY
		text = "Say",
		value = "SAY",
		func = sayToggle,
		checked = getCheckedSAY,
	},
	{ -- YELL
		text = "Yell",
		value = "YELL",
		func = yellToggle,
		checked = getCheckedYELL,
	},
	{ -- PARTY
		text = "Party",
		value = "PARTY",
		func = partyToggle,
		checked = getCheckedPARTY,
	},
	{ -- GUILD
		text = "Guild",
		value = "GUILD",
		func = guildToggle,
		checked = getCheckedGUILD,
	},
	{ -- OFFICER
		text = "Officer",
		value = "OFFICER",
		func = officerToggle,
		checked = getCheckedOFFICER,
	},
	{ -- RAID
		text = "Raid",
		value = "RAID",
		func = raidToggle,
		checked = getCheckedRAID,
	},
}

---------------------------------------------
-- EVENTS                                  --
---------------------------------------------
function Babel:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("BabelDB", defaults)
end

function Babel:OnEnable()
	self:RawHook("SendChatMessage","Translate",true)
	launcher.text = GetLanguageByIndex(Babel.db.char.language or 1)
end


----------------------------------------------
-- METHODS                                  --
----------------------------------------------
function Babel:Translate(msg, chatType, language, channel)
	if (chatType and self.db.char.types[chatType]) then
		language = GetLanguageByIndex(self.db.char.language)
	end
	self.hooks.SendChatMessage(msg,chatType,language, channel)
end

-----------------------------------------------
-- FUNCTIONS                                 --
-----------------------------------------------

local function selectLanguage(index)
	assert(index <= GetNumLanguages(), "Bad language chosen: " .. index)
	Babel.db.char.language = index
	launcher.text = GetLanguageByIndex(index)
end

-----------------------------------------------
-- FUNCTIONS                                 --
-----------------------------------------------

local launcher = ldb:NewDataObject( "Babel", {
	type = "data source",
	text = "Loading...",
	label = "Babel",
	icon = "Interface\\Addons\\Babel\\icon",
	OnClick = function(clickedframe, button)
		if button == "RightButton" then
			EasyMenu(menu_list,menu_frame,"cursor",0,0,"MENU",10)
		else
			selectLanguage(
			    ((Babel.db.char.language or 1) % GetNumLanguages()) + 1) -- Increment language index by 1
		end
	end,
	OnTooltipShow = function(tt)
		tt:AddLine("Babel")
		tt:AddLine("|cffffff00Click|r to toggle the active language.")
		tt:AddLine("|cffffff00Right-click|r to open the settings menu.")
	end,
} )